@@ -16,7 +16,11 @@ class PDF::Annot
 
     # See [PDF Spec 1.7 table 8.15 - Entries common to all annotation dictionaries ]
     has PDF::COS::Name $.Type is entry where 'Annot';
-    has PDF::COS::Name $.Subtype is entry(:required);
+    my subset AnnotName of PDF::COS::Name where 'Text'|'Link'|'FreeText'|'Line'|'Square'|
+        'Circle'|'Polygon'|'PolyLine'|'Highlight'|'Underline'|'Squiggly'|'StrikeOut'|
+        'Stamp'|'Caret'|'Ink'|'Popup'|'FileAttachment'|'Sound'|'Movie'|'Widget'|'Screen'|
+        'PrinterMark'|'TrapNet'|'Watermark'|'Redact';
+    has AnnotName $.Subtype is entry(:required);
     has Numeric @.Rect is entry(:required);                     #| (Required) The annotation rectangle, defining the location of the annotation on the page in default user space units.
     has PDF::COS::TextString $.Contents is entry;               #| (Optional) Text to be displayed for the annotation or, if this type of annotation does not display text, an alternate description of the annotation’s contents in human-readable form
     has Hash $.P is entry(:alias<page>);                        #| (Optional; PDF 1.3; not used in FDF files) An indirect reference to the page object with which this annotation is associated.
