@@ -10,8 +10,8 @@ class PDF::ColorSpace::Indexed
     use PDF::COS::Stream;
     use PDF::COS::ByteString;
     # see [PDF 1.7 Section 4.5.5 Special Color Spaces]
-    subset ArrayOrName where Array | PDF::COS::Name;
-    has ArrayOrName $.Base is index(1);
+    my subset NameOrColorSpace where PDF::COS::Name|PDF::ColorSpace;
+    has NameOrColorSpace $.Base is index(1);
     has UInt $.Hival is index(2);
     my subset StreamOrByteString where PDF::COS::Stream | PDF::COS::ByteString;
     has StreamOrByteString $.Lookup is index(3);
