@@ -1,18 +1,15 @@
 use v6;
 
-use PDF::COS::Dict;
 use PDF::COS::Tie::Hash;
 
-class PDF::Mask
-    is PDF::COS::Dict
+role PDF::Mask
     does PDF::COS::Tie::Hash {
 
     use PDF::COS::Tie;
     use PDF::COS::Name;
     use PDF::COS::Stream;
     #| /Type entry is optional, but should be /Mask when present
-    my subset Name-Mask of PDF::COS::Name where 'Mask';
-    has Name-Mask $.Type is entry;
+    has PDF::COS::Name $.Type is entry where 'Mask';
     method type {'Mask'}
 
     my subset MaskSubtype of PDF::COS::Name where 'Alpha'|'Luminosity';
